var step2Html = api.readFile({
    sync: true,
    path: 'widget://html/tweelog/modules/step2/step2.html'
})
MSG = JSON.parse(api.readFile({
    sync: true,
    path: 'widget://res/i18n/'+ lan +'.json'
}));
var step2 = Vue.component('step2', {
    template: step2Html,
    props: {
        tweelogdata: {
            default: function(){return {}},
            type: Object
        }
    },
    data(){
        return {
            message: MSG,
            email: "",
            faxNumber: "",
            phoneNumber: "",
            members: this.tweelogdata.members || [],
            socialShow: false,
            location: {},
            social: {
                WECHAT: "",
                FACEBOOK: "",
                TWITTER: "",
                WEIBO: "",
                INSTAGRAM: "",
                LINK: ""
            }
        }
    },
    created: function(){
        if (Object.keys(this.tweelogdata).length){
            this.email = this.tweelogdata.email || '';
            this.faxNumber = this.tweelogdata.faxNumber || '';
            this.phoneNumber = this.tweelogdata.phoneNumber || '';
            this.location = this.tweelogdata.location || {};
            if (this.tweelogdata.socials && this.tweelogdata.socials.length){
                this.tweelogdata.socials.forEach(function(item){
                    this.$set(this.social, item.socialType, item.socialAccount);
                }.bind(this));
                this.socialShow = true;
            }
            if (this.tweelogdata.type === 'PERSONAL'){
                this.members = this.tweelogdata.members.map(function(item){
                    return Object.assign({}, item, {contactMember: true});
                })
            }else {
                if (this.tweelogdata.contactMembers){
                    var memberMap = {}
                    this.tweelogdata.contactMembers.forEach(function(item){
                        memberMap[item.userId] = true;
                    });
                    this.members.forEach(function(item){
                        if (memberMap[item.userId]){
                            item.contactMember = true;
                        }
                    })
                }
            }
        }
        api.addEventListener({
            name: 'tweelogSelectConcats'
        }, function(ret, err){
            this.members = ret.value.members
        }.bind(this));
        api.addEventListener({
            name: 'tweelogSelectLocation'
        }, function(ret, err){
            this.location = ret.value.location;
        }.bind(this));
    },
    computed: {
        memberSelectCount:function(){
            return this.members.filter(function(item){
                return item.contactMember;
            }).length;
        }
    },
    methods:{
        checkData: function(){
            var promise = new Promise(function(resolve, reject) {
                var errorMessage = '';
                var socialList = [];
                var contact = this.members.filter(function(item){
                    return item.contactMember;
                });
                Object.keys(this.social).forEach(function(item, index){
                    if (this.social[item]){
                        socialList.push({
                            socialAccount: this.social[item],
                            socialType: item
                        });
                    }
                }.bind(this));
                if (!isEmail(this.email)){
                    errorMessage = MSG.tweeLog.emailError;
                }else if (!this.phoneNumber){
                    errorMessage = MSG.tweeLog.phoneError;
                }
                // else if (!this.faxNumber){
                //     errorMessage = MSG.tweeLog.faxError;
                // }
                else if (!contact.length){
                    errorMessage = MSG.tweeLog.concatError;
                }else if (this.socialShow && !socialList.length){
                    errorMessage = MSG.tweeLog.socialError;
                }else if (!this.location.address){
                    errorMessage = MSG.tweeLog.locationError;
                }

                if (errorMessage){
                    api.toast({
                        msg: errorMessage,
                        duration: 2000,
                        location: 'middle'
                    });
                }else {
                    var data = {
                        email: this.email,
                        phoneNumber: this.phoneNumber,
                        faxNumber: this.faxNumber,
                        socials: socialList,
                        contactMembers: contact,
                        location: {
                            address: this.location.address,
                            latitude: this.location.lat || this.location.latitude,
                            longitude: this.location.lon || this.location.longitude
                        }
                    }
                    loading('show');
                    apiTweelog.post('/api/v1/tweelog/sensitive', {
                        text: this.email + socialList.map(function(item){return item.socialAccount}).join(',')
                    }).then(function(res){
                        loading('hide');
                        if (!Number(res.code)){
                            resolve(data);
                        }else {
                            api.toast({
                                msg: res.message,
                                duration: 2000,
                                location: 'middle'
                            });
                        }
                    })
                }
            }.bind(this));
            return promise;
        },
        removeConcatMembers: function(user){
            var buttons = [
                {
                    color: 'red',
                    text: MSG.tweeLog.removeMembersConfirm,
                    callback: function () {
                        var index = 0;
                        this.members.forEach(function (item, inx) {
                            if (item.userId === user.userId) {
                                index = inx
                            }
                        }.bind(this))
                        const contactMember = user.contactMember
                        this.$set(this.members, index, Object.assign({}, user, {contactMember: !contactMember}))
                    }.bind(this)
                }
            ];
            actionSheet(buttons)
        },
        formatSearchResult: function (text, userId) {
            var result = '';
            if (userRemarkService.has(userId) === true) {
                result = text + ' (' + userRemarkService.get(userId) + ')'
            }
            return result;
        },
        selectLocation:function () {
            api.openFrame({
                name: 'location',
                url: 'widget://html/tweelog/modules/step2/location-page.html',
                bgColor:'rgba(0, 0, 0, 0.4)',
                rect: {
                    x: 0,
                    y: 0,
                    w: 'auto',
                    h: 'auto'
                },
                animation:{
                    type:"movein",
                    subType:"from_bottom",
                    duration:300
                },
                pageParam: {
                    type: ''
                }
            });
        },
        selectConcetMembers: function(){
            api.openFrame({
                name: 'tweelogSelectConcats',
                url: 'widget://html/tweelog/modules/step2/selectConcatMembers.html',
                bgColor:'rgba(0, 0, 0, 0.4)',
                rect: {
                    x: 0,
                    y: 0,
                    w: 'auto',
                    h: 'auto'
                },
                animation:{
                    type:"movein",
                    subType:"from_bottom",
                    duration:300
                },
                pageParam: {
                    members: this.members
                }
            });
        },
        goLocation: function(){
            api.openFrame({
                name: 'tweelogSelectLocation',
                url: 'widget://html/tweelog/modules/step2/location-page.html',
                bgColor:'rgba(0, 0, 0, 0.4)',
                rect: {
                    x: 0,
                    y: 0,
                    w: 'auto',
                    h: 'auto'
                },
                animation:{
                    type:"movein",
                    subType:"from_bottom",
                    duration:300
                },
                pageParam: {
                    members: this.members
                }
            });
        }
    }
})
