/**
 * @file 封装订单相关的通用方法
 * @author jinguangguo
 * @date 21/05/2020 1:10 PM
 */


/**
 * 订单状态
 * @param value
 * @returns {*}
 */
function filterOrderStatus(value) {
    /*
    10              Pending
    20              Processing
    30              Complete
    40              Cancelled
    50              Returned
    60              PartiallyShipped
    70              Paused
    80              ManualProcessing
     */
    switch (value) {
        case "Processing":
            return MSG.payment.transactionProcessing;
        case "Paused":
            return MSG.payment.paused;
        case "Pending":
            return MSG.payment.transactionPending;
        case "Complete":
            return MSG.payment.transactionComplete;
        case "Completed":
            return MSG.payment.transactionComplete;
        case "Cancelled":
            return MSG.payment.transactionCancelled;
        default:
            return value;
    }
}

/**
 * 支付状态
 * @param value
 * @returns {*|string}
 */
function filterPayStatus(value) {
    switch (value) {
        case "Pending":
            // 未付款
            return MSG.payment.unpaid;
        case "Paid":
            // 已付款
            return MSG.payment.paid;
        case "Refunded":
            // 已退款
            return MSG.payment.refunded;
    }
}

/**
 * 物流状态
 * @param value
 * @returns {*|string}
 */
function filterShippingStatus(value) {

    /*
    "SHIPPINGNOTREQUIRED"
    "NOTYETSHIPPED"	// 没填之前，未发货
    "PARTIALLYSHIPPED"
    "SHIPPED"	// 填完以后是这个，运输中
    "DELIVERED" // 已签收
     */
    if (value) {
        value = value.toUpperCase();
        switch (value) {
            // 未发货
            case 'NOTYETSHIPPED':
                return MSG.payment.shippingNot;
            case "SHIPPED":
                return MSG.payment.shipped;
            case "DELIVERED":
                return MSG.payment.shippingDelivered;
            default:
                return value;
        }
    }
}

function filterAppealStatus(value) {
    switch (value) {
        case "Correction":
            return '修改地址已提交';
        case "AgreedCancel":
            return '线下协商退款';
        case "ChangeMind":
            return '退货并退款';
    }
}

function filterSubString(value) {
    if (value && value.length > 15) {
        return value.substring(0, 15) + '...';
    }
    return value;
}

function filterTime(value) {
    return moment.utc(value).local().format('YYYY-MM-DD HH:mm:ss');
}

function filterTrackingState(value) {
    return MSG.trackingState['state'+value];
}
