apiready = function () {
    var components = [
        './modules/step0/step0.js',
        './modules/step1/step1.js',
        './modules/step2/step2.js',
        './modules/step3/step3.js',
        './modules/step4/step4.js'
    ];
    Promise.all(components.map(function (item) {
        return getScript(item)
    })).then(function () {
        init();
    });

    var kv = api.require('snKVStorage');

    function init() {
        //读取文字信息
        MSG = JSON.parse(api.readFile({
            sync: true,
            path: 'widget://res/i18n/' + lan + '.json'
        }));
        //改变导航右侧按钮
        var nextBtn = MSG.general.next;
        var postBtn = MSG.products.post;
        setRightBtn(nextBtn);

        function setRightBtn(text) {
            api.setNavBarAttr({
                rightButtons: [{
                    text: text,
                    color: '#4578F3',
                    fontSize: '15'
                }]
            });
        }

        new Vue({
            el: '#app',
            components: {
                step0,
                step1,
                step2,
                step3
            },
            data() {
                return {
                    message: MSG,
                    step: 0,
                    tweeLogData: {}
                }
            },
            mounted() {
                this.$el.style.display = 'block';
            },
            created() {
                api.addEventListener({
                    name: 'navitembtn'
                }, function (ret, err) {
                    if (ret.type === 'right') {
                        this.$children[0].checkData().then(function (data) {
                            // console.log(data)
                            var currentData = Object.assign({}, this.tweeLogData, data);
                            this.tweeLogData = currentData;
                            kv.setObject({
                                key: 'tweeLogData',
                                value: currentData
                            });
                            api.setTabLayoutAttr({
                                title: this.tweeLogData.type === 'PERSONAL' ? MSG.tweeLog.selectTweelogSingle
                                    : MSG.tweeLog.selectTweelogMultiple
                            });
                            if (this.step < 4) {
                                this.step++
                                if (this.step === 4) {
                                    setRightBtn(postBtn);
                                } else {
                                    setRightBtn(nextBtn);
                                }
                            } else {
                                this.save();
                            }
                        }.bind(this));
                    } else {
                        if (this.step === 0) {
                            back();
                        } else {
                            this.step--;
                            setRightBtn(nextBtn);
                        }
                    }
                }.bind(this));

                api.addEventListener({
                    name: 'keyback'
                }, function(ret, err) {
                    if (this.step === 0) {
                        back();
                    } else {
                        this.step--;
                        setRightBtn(nextBtn);
                    }
                }.bind(this));
            },
            computed: {
                currentTabComponent() {
                    return `step${this.step}`;
                },
            },
            methods: {
                getType: function (data) {
                    this.step++;
                    this.tweeLogData = Object.assign({}, this.tweeLogData, data);
                },
                createGroup: function (callback) {
                    var that = this;
                    var members = $.extend([], this.tweeLogData.members);
                    var creator = members[0];
                    members = members.slice(1);
                    var names = [creator.nickname];
                    var results = [
                        {
                            userName: creator.nickname,
                            avatar: creator.avatarUrl,
                            CustomerId: creator.userId,
                            userId: localStorage.getItem('chatID')
                        }
                    ];
                    $.map(members, function (item, index) {
                        results.push({
                            userName: item.storeName,
                            avatar: item.avatarUrl,
                            CustomerId: item.userId,
                            userId: item.userName + '@new'
                        });
                        names.push(item.storeName);
                    });
                    var symbol = lan === 'zh' ? '、' : ',';
                    var groupName = MSG.tweeLog.group + this.tweeLogData.name;
                    var groupData = {
                        "CreatorId": localStorage.getItem('chatID'),
                        "Members": results,
                        "Name": groupName
                    };
                    loading('show');
                    var url = getBaseUrl() + "/api/im/v1/imgroup";
                    getAxois(url, "POST", groupData).then(function (response) {
                        loading('hide');
                        //console.log(JSON.stringify(response));
                        if (response.data.Code === 0) {
                            api.sendEvent({
                                name: 'sendMessagesEvent',
                                extra: {
                                    type: 'text',
                                    targetId: response.data.Data.GroupId,
                                    conversationType: 'GROUP',
                                    msg: names.join(symbol) + MSG.chat.joinGroup,
                                    sendUserId: creator.userId,
                                    sendName: creator.nickname,
                                    sendPortrait: creator.avatarUrl,
                                    chatUserId: '',
                                    chatName: groupName,
                                    chatPortrait: that.tweeLogData.avatarUrl,
                                    textType: 'groupChat',
                                    Source: api.systemType
                                }
                            });
                            setTimeout(function () {
                                api.sendEvent({
                                    name: 'conversationListReload'
                                });
                            }, 500);
                            callback(response.data.Data.GroupId);
                        } else if (response.data.Code === 45024) {
                            loading('hide');
                            api.toast({
                                msg: MSG.chat.membersFull,
                                duration: 3000,
                                location: 'middle'
                            });
                            setTimeout(function () {
                                back();
                            }, 3000);
                        }

                    }).catch(function (error) {
                        console.log(JSON.stringify(error));
                    });
                },
                save: function () {
                    var that = this;

                    if (this.tweeLogData.type === 'COLLAB') {
                        this.createGroup(function (groupId) {
                            start(groupId);
                        });
                    } else {
                        start();
                    }

                    function start(groupId) {
                        var params = $.extend({}, that.tweeLogData);
                        if (groupId) {
                            params.groupId = groupId;
                        }

                        // 变参数 - 产品列表
                        var resultProducts = [];
                        $.map(params.products, function (item, index) {
                            resultProducts.push({
                                displayOrder: index,
                                id: item.Id
                            })
                        });
                        params.products = resultProducts;

                        // 瞬间列表
                        var resultMoments = [];
                        $.map(params.moments, function (item, index) {
                            resultMoments.push({
                                displayOrder: index,
                                id: item.blogPostId
                            })
                        });
                        params.moments = resultMoments;

                        // 联系成员呢
                        params.contactMembers = params.contactMembers.map(function (item) {
                            return item.userId
                        });

                        console.log(JSON.stringify(params));
                        loading('show');
                        apiTweelog.post('/api/v1/tweelog', params).done(function (rep) {
                            loading('hide');
                            if (rep.code === 0) {
                                api.sendEvent({
                                    name: 'reloadMyTweelog'
                                });
                                api.sendEvent({
                                    name: 'tweelogReloadList'
                                });
                                api.toast({
                                    msg: MSG.tweeLog.releaseSuccess,
                                    duration: 2000,
                                    location: 'middle'
                                });
                                setTimeout(function () {
                                    back();
                                }, 2000);
                            } else {
                                api.toast({
                                    msg: rep.message,
                                    duration: 2000,
                                    location: 'middle'
                                });
                                // 解散群聊
                                if (groupId) {
                                    var params = {
                                        "GroupId": groupId,
                                        "UserId": localStorage.getItem('chatID')
                                    };
                                    getAxois(getBaseUrl() + "api/im/v1/imgroup", "DELETE", params).then(function (response) {
                                        var rong = api.require('rongCloud2');
                                        rong.removeConversation({
                                            conversationType: 'GROUP',
                                            targetId: groupId
                                        }, function(ret, err) {
                                            loading('hide');
                                        });
                                    }).catch(function (error) {
                                        loading('hide');
                                        console.log(JSON.stringify(error));
                                    });
                                }
                            }
                        });
                    }
                },
                back: function () {
                    this.step--;
                    if (this.step === 0) {
                        api.setTabLayoutAttr({
                            title: MSG.tweeLog.createTweelog
                        });
                    }
                }
            }
        })
    }

}
