/**
 * @file
 * @author jinguangguo
 * @date 05/07/2020 1:34 PM
 */

/**
 * 处理 移动设备上的 点击、长按、左右上下滑动 事件
 *
 * =========================================
 * 导出了7个自定义指令：
 *  v-tap： tap点击事件
 *  v-swipe： swipe滑动事件
 *  v-swipeleft： swipeleft左滑事件
 *  v-swiperight： swiperight右滑事件
 *  v-swipedown： swipedown下滑
 *  v-swipeup： swipeup上滑
 *  v-longtap： longtap长按
 * =========================================
 *
 * =========================================
 * 包含四个参数
 * stop 阻止冒泡
 * prevent 阻止默认事件
 * self 只当在 event.target 是当前元素自身时触发处理函数
 * once 执行一次后解绑
 *
 * @example v-tap.stop.prevent.self.once
 * =========================================
 *
 * =========================================
 * 事件绑定有两种方式
 * @example
 *  1. v-tap="showDialog" 绑定一个方法对象
 *  2. v-tap="{fn:click123, param1:1, param2:2, param3:{aaa:'123'} ...}"
 *      绑定一个JSON字面量，fn是执行的方法，后边的是需要传递的参数
 * 事件回调参数
 * @param 第一个参数是event，事件对象
 * @param 第二个参数是 binding.value，也就是v-tap=""双引号中的部分（如示例2，第二个参数就是 {fn:click123, param1:1, param2:2, param3:{aaa:'123'} ...}）
 * =========================================
 *
 * @update
 *  1. 根据MUI进行了滑动事件的判断修正
 *  2. 根据TouchEvent修正了点击位置的判断
 *
 */

"use strict";

var VueTouch = function () {

    function _instanceof(left, right) {
        if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) {
            return !!right[Symbol.hasInstance](left);
        } else {
            return left instanceof right;
        }
    }

    function _typeof(obj) {
        "@babel/helpers - typeof";
        if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
            _typeof = function _typeof(obj) {
                return typeof obj;
            };
        } else {
            _typeof = function _typeof(obj) {
                return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
            };
        }
        return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
        if (!_instanceof(instance, Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _defineProperties(target, props) {
        for (var i = 0; i < props.length; i++) {
            var descriptor = props[i];
            descriptor.enumerable = descriptor.enumerable || false;
            descriptor.configurable = true;
            if ("value" in descriptor) descriptor.writable = true;
            Object.defineProperty(target, descriptor.key, descriptor);
        }
    }

    function _createClass(Constructor, protoProps, staticProps) {
        if (protoProps) _defineProperties(Constructor.prototype, protoProps);
        if (staticProps) _defineProperties(Constructor, staticProps);
        return Constructor;
    }

    /**
     * @param el 绑定的DOM
     * @param binding 自定义指令中的binding对象
     * @param type 绑定的事件类型
     */
    function VueTouch(el, binding, type) {
        _classCallCheck(this, VueTouch);

        var g = this;
        g.obj = el;
        g.binding = binding;
        g.touchType = type;
        g.firstTouchPosition = {
            x: 0,
            y: 0
        };
        g.firstTouchTime = 0;
        /**
         * =========================================
         * 事件绑定有两种方式
         * @example
         *  1. v-tap="showDialog" 绑定一个方法对象
         *  2. v-tap="{fn:click123, param1:1, param2:2, param3:{aaa:'123'} ...}"
         *      绑定一个JSON字面量，fn是执行的方法，后边的是需要传递的参数
         * 事件回调参数
         * @param 第一个参数是event，事件对象
         * @param 第二个参数是 binding.value，也就是v-tap=""双引号中的部分（如示例2，第二个参数就是 {fn:click123, param1:1, param2:2, param3:{aaa:'123'} ...}）
         * =========================================
         */

        g.callBack = _typeof(binding.value) === "object" ? binding.value.fn : binding.value; // 事件监听回调集合

        var _listener = Object.create(null); // 事件方法


        var _listen = function _listen(type) {
            return function (e) {
                /**
                 * 取出修饰符（和v-on的一样）
                 */
                var _g$binding$modifiers = g.binding.modifiers,
                    stop = _g$binding$modifiers.stop,
                    prevent = _g$binding$modifiers.prevent,
                    self = _g$binding$modifiers.self,
                    once = _g$binding$modifiers.once; // 配置判断

                if (stop) e.stopPropagation();
                if (prevent) e.preventDefault();
                if (once) g.obj.removeEventListener("touch" + type, _listener[type]);
                if (self && e.target !== e.currentTarget) return;
                g[type](e);
            };
        };

        _listener.start = _listen('start');
        _listener.end = _listen('end');
        _listener.move = _listen('move'); // 事件绑定

        this.obj.addEventListener("touchstart", _listener.start, false);
        this.obj.addEventListener("touchend", _listener.end, false);
        this.obj.addEventListener("touchmove", _listener.move, false);
    } // 点击开始


    _createClass(VueTouch, [{
        key: "start",
        value: function start(e) {
            var g = this; // @update 2018.3.26 这里做了一个修改

            g.moved = false; //是否移动了

            g.leaved = false; //是否离开了

            g.longTouched = false; //是否执行了长按操作
            // 获取开始点击位置和时间

            g.firstTouchPosition = g.getMultiCenter(e.changedTouches);
            g.firstTouchTime = e.timeStamp; // 判断长按操作 @TODO 稍微有点触发时机上的问题，待修正

            g.time = setTimeout(function () {
                if (!g.leaved && !g.moved) {
                    e.stopPropagation();
                    g.touchType === "longtap" && g.callBack(e, g.binding.value);
                    g.longTouched = true;
                }
            }.bind(g), 1000);
        } // 点击结束

    }, {
        key: "end",
        value: function end(e) {
            var g = this; // 点击结束获取点击位置并计算位移和时差

            var _g$getMultiCenter = g.getMultiCenter(e.changedTouches),
                x = _g$getMultiCenter.x,
                y = _g$getMultiCenter.y;

            var _disX = x - g.firstTouchPosition.x;

            var _disY = y - g.firstTouchPosition.y;

            var _dis = Math.sqrt(_disX * _disX + _disY * _disY);

            var _timeDis = e.timeStamp - g.firstTouchTime;

            clearTimeout(g.time); // 计算滑动角度

            var _angle = this.getAngle(_disX, _disY); // 判断滑动方向

            // console.log('_disX: ' + _timeDis, '_disY: ' + _disY, '_dis: ' + _dis);
            // console.log('_timeDis: ' + _timeDis);
            // console.log('_angle: ' + _angle);

            if (_dis > 18 && _timeDis < 300) {
                g.touchType === "swipe" && g.callBack(e, g.binding.value);
                if (_angle >= 60 && _angle <= 120) {
                    g.touchType === "swipedown" && g.callBack(e, g.binding.value);
                }
                if (_angle <= -60 && _angle >= -120) {
                    g.touchType === "swipeup" && g.callBack(e, g.binding.value);
                }
                if (_angle <= 20 && _angle >= -20) {
                    g.touchType === "swipeleft" && g.callBack(e, g.binding.value);
                }
                if (_angle <= -160 && _angle > -180 || _angle >= 160 && _angle <= 180) {
                    g.touchType === "swiperight" && g.callBack(e, g.binding.value);
                }
            } else {
                if (!g.longTouched && !g.moved) {
                    g.touchType === "tap" && g.callBack(e, g.binding.value);
                    g.leaved = true;
                }
            }
        }
    }, {
        key: "move",
        value: function move() {
            this.moved = true;
        }
        /**
         * 获取点击集合的中心坐标
         * @param touches touch对象集合
         * @return {{x: number, y: number}}
         */

    }, {
        key: "getMultiCenter",
        value: function getMultiCenter(touches) {
            var g = this,
                x = 0,
                y = 0;
            var _length = touches.length;

            for (var i = 0; i < _length; i++) {
                x += touches[i].pageX;
                y += touches[i].pageY;
            }

            return {
                x: Math.round(x / _length),
                y: Math.round(y / _length)
            };
        }
    }, {
        key: "getAngle",

        /**
         * 获取滑动的角度
         * @param disX X轴的位移
         * @param disY Y轴的位移
         * @return 角度
         */
        value: function getAngle(disX, disY) {
            var g = this;
            if (typeof disX !== 'number' || typeof disY !== 'number') return 45;
            return Math.atan2(disY, disX) * 180 / Math.PI;
        }
    }]);

    return VueTouch;
}();

Vue.directive("tap", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "tap");
    }
});
Vue.directive("swipe", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "swipe");
    }
});
Vue.directive("swipeleft", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "swipeleft");
    }
});
Vue.directive("swiperight", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "swiperight");
    }
});
Vue.directive("swipedown", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "swipedown");
    }
});
Vue.directive("swipeup", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "swipeup");
    }
});
Vue.directive("longtap", {
    bind: function (el, binding) {
        new VueTouch(el, binding, "longtap");
    }
});
